#!/usr/bin/env python
import os, sys

if not __package__:
  path = os.path.join(os.path.dirname(__file__), os.pardir)
  sys.path.insert(0, path)

from re_name import renamer
renamer.Renamer().update()



import os

class Renamer:

    def __init__(self):
        self.currentPath = os.getcwd()
        print('Current path:' + self.currentPath)

    def update(self):
        print('Renamer update is called!')
